<?php

namespace Litecms\BoardClient\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\BoardClient\Http\Requests\BoardClientRequest;
use Litecms\BoardClient\Interfaces\BoardClientRepositoryInterface;
use Litecms\BoardClient\Models\BoardClient;

/**
 * Resource controller class for board_client.
 */
class BoardClientResourceController extends BaseController
{

    /**
     * Initialize board_client resource controller.
     *
     * @param type BoardClientRepositoryInterface $board_client
     *
     * @return null
     */
    public function __construct(BoardClientRepositoryInterface $board_client)
    {
        parent::__construct();
        $this->repository = $board_client;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\BoardClient\Repositories\Criteria\BoardClientResourceCriteria::class);
    }

    /**
     * Display a list of board_client.
     *
     * @return Response
     */
    public function index(BoardClientRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\BoardClient\Repositories\Presenter\BoardClientPresenter::class)
                ->$function();
        }

        $board_clients = $this->repository->paginate();

        return $this->response->title(trans('board_client::board_client.names'))
            ->view('board_client::board_client.index', true)
            ->data(compact('board_clients'))
            ->output();
    }

    /**
     * Display board_client.
     *
     * @param Request $request
     * @param Model   $board_client
     *
     * @return Response
     */
    public function show(BoardClientRequest $request, BoardClient $board_client)
    {

        if ($board_client->exists) {
            $view = 'board_client::board_client.show';
        } else {
            $view = 'board_client::board_client.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('board_client::board_client.name'))
            ->data(compact('board_client'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new board_client.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BoardClientRequest $request)
    {

        $board_client = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('board_client::board_client.name')) 
            ->view('board_client::board_client.create', true) 
            ->data(compact('board_client'))
            ->output();
    }

    /**
     * Create new board_client.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BoardClientRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $board_client                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('board_client::board_client.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('board_client/board_client/' . $board_client->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/board_client/board_client'))
                ->redirect();
        }

    }

    /**
     * Show board_client for editing.
     *
     * @param Request $request
     * @param Model   $board_client
     *
     * @return Response
     */
    public function edit(BoardClientRequest $request, BoardClient $board_client)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('board_client::board_client.name'))
            ->view('board_client::board_client.edit', true)
            ->data(compact('board_client'))
            ->output();
    }

    /**
     * Update the board_client.
     *
     * @param Request $request
     * @param Model   $board_client
     *
     * @return Response
     */
    public function update(BoardClientRequest $request, BoardClient $board_client)
    {
        try {
            $attributes = $request->all();

            $board_client->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('board_client::board_client.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('board_client/board_client/' . $board_client->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('board_client/board_client/' . $board_client->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the board_client.
     *
     * @param Model   $board_client
     *
     * @return Response
     */
    public function destroy(BoardClientRequest $request, BoardClient $board_client)
    {
        try {

            $board_client->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('board_client::board_client.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('board_client/board_client/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('board_client/board_client/' . $board_client->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple board_client.
     *
     * @param Model   $board_client
     *
     * @return Response
     */
    public function delete(BoardClientRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('board_client::board_client.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('board_client/board_client'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/board_client/board_client'))
                ->redirect();
        }

    }

    /**
     * Restore deleted board_clients.
     *
     * @param Model   $board_client
     *
     * @return Response
     */
    public function restore(BoardClientRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('board_client::board_client.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/board_client/board_client'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/board_client/board_client/'))
                ->redirect();
        }

    }

}
